==> o365-3.0.1.tar.gz: o365/modules/o365_profile/src/Controller/O365ProfileAjaxController.php <==
<?php

namespace Drupal\o365_profile\Controller;

use Drupal\Component\Utility\Html;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\externalauth\Authmap;
use Drupal\o365_profile\O365ProfileGetDataService;
use Drupal\user\Entity\User;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Returns responses for Office 365 - Profiles and Personas routes.
 */
class O365ProfileAjaxController extends ControllerBase {

  /**
   * The externalauth authmap service.
   *
   * @var \Drupal\externalauth\Authmap
   */
  protected $authmap;

  /**
   * The service we use to get user data.
   *
   * @var \Drupal\o365_profile\O365ProfileGetDataService
   */
  protected $getDataService;

  /**
   * The controller constructor.
   */
  public function __construct(Authmap $authmap, O365ProfileGetDataService $getDataService) {
    $this->authmap = $authmap;
    $this->getDataService = $getDataService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('externalauth.authmap'), $container->get('o365_profile.get_data')
    );
  }

  /**
   * Generate the AJAX JSON response.
   *
   * @param int $uid
   *   The users UID.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON we use in JS.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \GuzzleHttp\Exception\GuzzleException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   */
  public function getUserStatus($uid) {
    $return = [];
    $auth = $this->authmap->get($uid, 'o365_sso');
    if (!empty($auth)) {
      $user = User::load($uid);
      if ($user) {
        $return['mail'] = $user->getEmail();
        $return['displayName'] = $user->getDisplayName();

        $userData = $this->getDataService->getProfileData($auth);
        $return['initials'] = $userData['initials'];
        $return['user_img'] = $userData['imageSrc'];

        if (isset($userData['presenceData']['activity'])) {
          $return['presence'] = $userData['presenceData']['activity'];
          $class = Html::cleanCssIdentifier($userData['presenceData']['activity']);
          $return['presence_class'] = strtolower($class);
        }

        if (isset($userData['userData']['givenName'])) {
          $return['givenName'] = $userData['userData']['givenName'];
        }

        if (isset($userData['userData']['surname'])) {
          $return['surname'] = $userData['userData']['surname'];
        }

        if (isset($userData['userData']['businessPhones'])) {
          $return['businessPhones'] = $userData['userData']['businessPhones'][0];
          $businessText = new TranslatableMarkup('Call on business phone');
          $return['businessPhones'] = [
            'number' => $userData['userData']['businessPhones'][0],
            'text' => $businessText->render(),
          ];
        }

        if (isset($userData['userData']['mobilePhone'])) {
          $mobileText = new TranslatableMarkup('Call on mobile phone');
          $return['mobilePhone'] = [
            'number' => $userData['userData']['mobilePhone'],
            'text' => $mobileText->render(),
          ];
        }

        $callText = new TranslatableMarkup('Call with Teams');
        $return['call'] = [
          'url' => 'https://teams.microsoft.com/l/call/0/0?users=' . $user->getEmail(),
          'text' => $callText->render(),
        ];
        $chatText = new TranslatableMarkup('Chat with Teams');
        $return['chat'] = [
          'url' => 'https://teams.microsoft.com/l/chat/0/0?users=' . $user->getEmail(),
          'text' => $chatText->render(),
        ];
        $videocallText = new TranslatableMarkup('Video call with Teams');
        $return['videocall'] = [
          'url' => 'https://teams.microsoft.com/l/call/0/0?users=' . $user->getEmail() . '&Withvideo=true',
          'text' => $videocallText->render(),
        ];
      }
    }

    return new JsonResponse($return);
  }

}

==> o365-5.0.8.tar.gz: o365/modules/o365_profile/src/Controller/O365ProfileAjaxController.php <==
<?php

namespace Drupal\o365_profile\Controller;

use Drupal\Component\Utility\Html;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\externalauth\Authmap;
use Drupal\o365_profile\O365ProfileGetDataService;
use Drupal\user\Entity\User;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;

/**
 * Returns responses for Office 365 - Profiles and Personas routes.
 */
class O365ProfileAjaxController extends ControllerBase {

  /**
   * The externalauth authmap service.
   *
   * @var \Drupal\externalauth\Authmap
   */
  protected $authmap;

  /**
   * The service we use to get user data.
   *
   * @var \Drupal\o365_profile\O365ProfileGetDataService
   */
  protected $getDataService;

  /**
   * The controller constructor.
   */
  public function __construct(Authmap $authmap, O365ProfileGetDataService $getDataService) {
    $this->authmap = $authmap;
    $this->getDataService = $getDataService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('externalauth.authmap'), $container->get('o365_profile.get_data')
    );
  }

  /**
   * Generate the AJAX JSON response.
   *
   * @param int $uid
   *   The users UID.
   *
   * @return \Symfony\Component\HttpFoundation\JsonResponse
   *   The JSON we use in JS.
   *
   * @throws \Drupal\Core\TempStore\TempStoreException
   * @throws \GuzzleHttp\Exception\GuzzleException
   * @throws \League\OAuth2\Client\Provider\Exception\IdentityProviderException
   */
  public function getUserStatus($uid) {
    $return = [];
    $auth = $this->authmap->get($uid, 'o365_sso');
    if (!empty($auth)) {
      $user = User::load($uid);
      if ($user) {
        $return = [];
        $return['mail'] = $user->getEmail();
        $return['displayName'] = $user->getDisplayName();

        $userData = $this->getDataService->getProfileData($auth);
        $return['initials'] = $userData['initials'];
        $return['user_img'] = $userData['imageSrc'];

        if (isset($userData['presenceData']['activity']) && !empty($userData['presenceData']['activity'])) {
          $return['presence'] = $userData['presenceData']['activity'];
          $class = Html::cleanCssIdentifier($userData['presenceData']['activity']);
          $return['presence_class'] = strtolower($class);
        }

        if (isset($userData['userData']['givenName']) && !empty($userData['userData']['givenName'])) {
          $return['givenName'] = $userData['userData']['givenName'];
        }

        if (isset($userData['userData']['surname']) && !empty($userData['userData']['surname'])) {
          $return['surname'] = $userData['userData']['surname'];
        }

        if (isset($userData['userData']['businessPhones']) && !empty($userData['userData']['businessPhones'])) {
          $businessText = new TranslatableMarkup('Call on business phone');
          $return['businessPhones'] = [
            'number' => $userData['userData']['businessPhones'][0],
            'text' => $businessText->render(),
          ];
        }

        if (isset($userData['userData']['mobilePhone']) && !empty($userData['userData']['mobilePhone'])) {
          $mobileText = new TranslatableMarkup('Call on mobile phone');
          $return['mobilePhone'] = [
            'number' => $userData['userData']['mobilePhone'],
            'text' => $mobileText->render(),
          ];
        }

        $callText = new TranslatableMarkup('Call with Teams');
        $return['call'] = [
          'url' => 'https://teams.microsoft.com/l/call/0/0?users=' . $user->getEmail(),
          'text' => $callText->render(),
        ];
        $chatText = new TranslatableMarkup('Chat with Teams');
        $return['chat'] = [
          'url' => 'https://teams.microsoft.com/l/chat/0/0?users=' . $user->getEmail(),
          'text' => $chatText->render(),
        ];
        $videocallText = new TranslatableMarkup('Video call with Teams');
        $return['videocall'] = [
          'url' => 'https://teams.microsoft.com/l/call/0/0?users=' . $user->getEmail() . '&Withvideo=true',
          'text' => $videocallText->render(),
        ];
      }
    }

    return new JsonResponse($return);
  }

}
